==> haskell-regex-compat-tdfa-0.95.1.4-218-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-regex-compat-tdfa.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 regex-compat-tdfa
version:              0.95.1.4
visibility:           public
id:                   regex-compat-tdfa-0.95.1.4-9cGQq8yaYqT7NbpNQtmyFY
key:                  regex-compat-tdfa-0.95.1.4-9cGQq8yaYqT7NbpNQtmyFY
license:              BSD-3-Clause
copyright:
    Copyright (c) Christopher Kuklewicz 2006
    (c) shelarcy 2012

maintainer:           shelarcy <shelarcy@gmail.com>
author:               Christopher Kuklewicz
stability:            Seems to work, passes a few tests
homepage:             http://hub.darcs.net/shelarcy/regex-compat-tdfa
package-url:          http://hackage.haskell.org/package/regex-compat-tdfa
synopsis:             Unicode Support version of Text.Regex, using regex-tdfa
description:
    One module layer over regex-tdfa to replace Text.Regex.

    regex-compat can'\''t use Unicode characters correctly because
    of using regex-posix. This is not good for Unicode users.

    I modified regex-compat to use regex-tdfa for solving today'\''s
    problem.

category:             Text
abi:                  ea28d1735c43ec825ddc5b7fbe218d83
exposed:              True
exposed-modules:      Text.Regex
import-dirs:          /usr/lib/ghc-9.2.8/site-local/regex-compat-tdfa-0.95.1.4
library-dirs:         /usr/lib/ghc-9.2.8/site-local/regex-compat-tdfa-0.95.1.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-regex-compat-tdfa
hs-libraries:         HSregex-compat-tdfa-0.95.1.4-9cGQq8yaYqT7NbpNQtmyFY
depends:
    array-0.5.4.0 base-4.16.4.0
    regex-base-0.94.0.2-6On48UZuN5IJxnL3aRqiWN
    regex-tdfa-1.3.2.2-1xhjl1IlCf4FpybsqAXAC1

haddock-interfaces:
    /usr/share/doc/haskell-regex-compat-tdfa/html/regex-compat-tdfa.haddock

haddock-html:         /usr/share/doc/haskell-regex-compat-tdfa/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-regex-compat-tdfa-0.95.1.4-219-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-regex-compat-tdfa.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 regex-compat-tdfa
version:              0.95.1.4
visibility:           public
id:                   regex-compat-tdfa-0.95.1.4-GYwNsxdGuEnChmtoljJg46
key:                  regex-compat-tdfa-0.95.1.4-GYwNsxdGuEnChmtoljJg46
license:              BSD-3-Clause
copyright:
    Copyright (c) Christopher Kuklewicz 2006
    (c) shelarcy 2012

maintainer:           shelarcy <shelarcy@gmail.com>
author:               Christopher Kuklewicz
stability:            Seems to work, passes a few tests
homepage:             http://hub.darcs.net/shelarcy/regex-compat-tdfa
package-url:          http://hackage.haskell.org/package/regex-compat-tdfa
synopsis:             Unicode Support version of Text.Regex, using regex-tdfa
description:
    One module layer over regex-tdfa to replace Text.Regex.

    regex-compat can'\''t use Unicode characters correctly because
    of using regex-posix. This is not good for Unicode users.

    I modified regex-compat to use regex-tdfa for solving today'\''s
    problem.

category:             Text
abi:                  b24cdff8f05f6ef4de7866205c1a3728
exposed:              True
exposed-modules:      Text.Regex
import-dirs:          /usr/lib/ghc-9.2.8/site-local/regex-compat-tdfa-0.95.1.4
library-dirs:         /usr/lib/ghc-9.2.8/site-local/regex-compat-tdfa-0.95.1.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-regex-compat-tdfa
hs-libraries:         HSregex-compat-tdfa-0.95.1.4-GYwNsxdGuEnChmtoljJg46
depends:
    array-0.5.4.0 base-4.16.4.0
    regex-base-0.94.0.2-6On48UZuN5IJxnL3aRqiWN
    regex-tdfa-1.3.2.2-Jqk1ZMahmcyCwODZUJ39zs

haddock-interfaces:
    /usr/share/doc/haskell-regex-compat-tdfa/html/regex-compat-tdfa.haddock

haddock-html:         /usr/share/doc/haskell-regex-compat-tdfa/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
